==> mysql-8.0.18.tar.gz: mysql-8.0.18/packaging/deb-in/deb_commercial.cmake <==
# Copyright (c) 2017, 2019, Oracle and/or its affiliates. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2.0,
# as published by the Free Software Foundation.
#
# This program is also distributed with certain software (including
# but not limited to OpenSSL) that is licensed under separate terms,
# as designated in a particular file or component or in included license
# documentation.  The authors of MySQL hereby grant you an additional
# permission to link the program and your derivative works with the
# separately licensed software that they have included with MySQL.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License, version 2.0, for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

SET (DEB_COMMERCIAL_CONTROL_EXTRAS "
Package: mysql-${DEB_PRODUCTNAME}-backup
Architecture: any
Depends: \${shlibs:Depends}, \${misc:Depends}
Conflicts: meb
Description: MySQL Enterprise Backup
 Tool for MySQL Backup
")

SET (DEB_CMAKE_EXTRAS "${DEB_CMAKE_EXTRAS} -DWITH_MEB=1 -DMYSQL_SERVER_SUFFIX=\"-commercial\"")
SET (DEB_CONTROL_BDEPS_COMMERCIAL ", libcurl4-openssl-dev")

==> mysql-8.0.21.tar.gz: mysql-8.0.21/packaging/deb-in/deb_commercial.cmake <==
# Copyright (c) 2017, 2020, Oracle and/or its affiliates. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2.0,
# as published by the Free Software Foundation.
#
# This program is also distributed with certain software (including
# but not limited to OpenSSL) that is licensed under separate terms,
# as designated in a particular file or component or in included license
# documentation.  The authors of MySQL hereby grant you an additional
# permission to link the program and your derivative works with the
# separately licensed software that they have included with MySQL.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License, version 2.0, for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

SET (DEB_COMMERCIAL_CONTROL_EXTRAS "
Package: mysql-${DEB_PRODUCTNAME}-backup
Architecture: any
Depends: \${shlibs:Depends}, \${misc:Depends}
Conflicts: meb
Description: MySQL Enterprise Backup
 Tool for MySQL Backup
")

SET (DEB_CMAKE_EXTRAS "${DEB_CMAKE_EXTRAS} -DWITH_MEB=1 -DMYSQL_SERVER_SUFFIX=\"-commercial\"")
SET (DEB_CONTROL_BDEPS_COMMERCIAL ", libcurl4-openssl-dev, libkrb5-dev, libsasl2-modules-gssapi-mit")
